@@ -43,6 +43,7 @@
 #include "tempfile.h"
 #include "cpp.h"
 #include "filename.h"
+#include "arg.h"
 
 
 /**
@@ -54,11 +55,6 @@
  * wait for @p cpp_fid to exit before the output is complete.  This
  * allows us to overlap opening the TCP socket, which probably doesn't
  * use many cycles, with running the preprocessor.
- *
- * Rather than setting -o, we could capture stdout from cpp, remove the -o
- * option, add -E, and look at the results of that.  That might avoid problems
- * with compilers that have trouble with -o and -E.  This may include some
- * versions of gcc?
  **/
 int dcc_cpp_maybe(char **argv, char *input_fname, char **cpp_fname,
 		  pid_t *cpp_pid)
@@ -82,41 +78,21 @@ int dcc_cpp_maybe(char **argv, char *input_fname, char **cpp_fname,
         return 0;
     }
 
-    /* TODO: Really we ought to centralize determination of file type. */
-    /* TODO: Does this also affect the server temporary file?  It ought to. */
-
     input_exten = dcc_find_extension(input_fname);
     output_exten = dcc_preproc_exten(input_exten);
     *cpp_fname = dcc_make_tmpnam("cppout", output_exten);
 
-
-    /* FIXME: Stripping -o fixes some, but not all problems with -MD.
+    /* We strip the -o option and allow cpp to write to stdout, which is
+     * caught in a file.  Sun cc doesn't understand -E -o, and gcc screws up
+     * -MD -E -o.
      *
-     * It does fix compilers that can't handle -E -o, such as Sun.
-     *
-     * It also avoids gcc-3.2 sending dependencies to the -o file with -MD -E.
-     *
-     * gcc-3.2 with -MD without -E determines the output file based on whether
-     * a -o option is given.
-     *
-     * I think at the moment distcc may cause dependencies to be written to
-     * the source directory, when plain gcc may write them to the output
-     * directory.
-     *
-     * We could fix that by synthesizing a -MF option if one is needed and not
-     * present, by reimplementing gcc's rules for deciding where to put it.
-     *
-     * However that has several problems: gcc-2.95 doesn't have a -MF option,
-     * and in any case it puts the default .d file in the working directory
-     * rather than the source or output directory.
-     *
-     * So this change allows you to get dependencies; but if you're not
-     * building everything in a single directory you need to use -MF to set
-     * the output location.
-     *
-     * As a workaround people might just specify a -MF option.
-     */
-
+     * There is still a problem here with -MD -E -o, gcc writes dependencies
+     * to a file determined by the source filename.  We could fix it by
+     * generating a -MF option, but that would break compilation with older
+     * versions of gcc.  This is only a problem for people who have the source
+     * and objects in different directories, and who don't specify -MF.  They
+     * can fix it by specifying -MF.  */
+    
     if ((ret = dcc_strip_dasho(argv, &cpp_argv))
         || (ret = dcc_set_action_opt(cpp_argv, "-E")))
         return ret;
