@@ -228,6 +228,18 @@ static void dcc_setup_real_log(void)
 }
 
 
+int dcc_log_daemon_started(const char *role)
+{
+    rs_log_info("%s started (%s %s, built %s %s)",
+                role,
+                PACKAGE_VERSION,
+                GNU_HOST, 
+                __DATE__, __TIME__);
+
+    return 0;
+}
+
+
 /**
  * Serve a single file on stdin, and then exit.
  **/
@@ -238,8 +250,7 @@ static int dcc_inetd_server(void)
     struct sockaddr *psa = (struct sockaddr *) &ss;
     socklen_t len = sizeof ss;
     
-    rs_log_info("inetd server started (version %s, built %s %s)", PACKAGE_VERSION,
-                __DATE__, __TIME__);
+    dcc_log_daemon_started("inetd server");
 
     /* XXX: ssh seems to open us using a unix domain socket.  Is that always
      * the case? */
@@ -248,7 +259,7 @@ static int dcc_inetd_server(void)
         len = 0;
     }
 
-    ret = dcc_service_job(STDIN_FILENO, psa, len);
+    ret = dcc_service_job(STDIN_FILENO, STDOUT_FILENO, psa, len);
 
     close_ret = dcc_close(STDIN_FILENO);
 
