@@ -20,7 +20,6 @@
  * USA
  */
 
-#define PROTO_VER 1
 
 #ifdef NORETURN
 /* nothing */
@@ -55,29 +54,27 @@ typedef int sa_family_t;
 struct dcc_hostdef;
 
 
+
+
+
+
+enum dcc_compress {
+    /* wierd values to catch errors */
+    DCC_COMPRESS_NONE     = 69,
+    DCC_COMPRESS_LZO1X
+};
+
+enum dcc_protover {
+    DCC_VER_1   = 1,            /**< vanilla */
+    DCC_VER_2   = 2             /**< ditto with LZO sprinkles */
+};
+
+
+
 int str_endswith(const char *tail, const char *tiger);
 
 
 
-/* filename.c */
-int dcc_is_source(const char *sfile);
-int dcc_is_preprocessed(const char *sfile);
-char * dcc_find_extension(char *sfile);
-int dcc_output_from_source(const char *sfile, const char *out_extn,
-                           char **ofile);
-
-/* arg.c */
-int dcc_deepcopy_argv(char **, /*@relnull@*/ char ***);
-int dcc_shallowcopy_argv(char **, /*@relnull@*/ char ***, int);
-int dcc_set_action_opt(char **, const char *);
-int dcc_set_output(char **, char *);
-int dcc_set_input(char **, char *);
-int dcc_scan_args(char *argv[], /*@out@*/ /*@relnull@*/ char **orig_o,
-                  char **orig_i, char ***ret_newargv);
-char *dcc_argv_tostr(char **a);
-
-int dcc_argv_len(char **a);
-
 
 /* A macro so that we get the right __FUNCTION__ in the trace message.
  *
@@ -93,10 +90,6 @@ int dcc_argv_len(char **a);
     } else {}
 
 
-/* dopt.c */
-extern struct dcc_allow_list *opt_allowed;
-int distccd_parse_options(int argc, const char *argv[]);
-
 /* help.c */
 int dcc_trace_version(void);
 int dcc_show_copyright(void);
@@ -123,6 +116,17 @@ int dcc_ssh_connect(char *ssh_cmd, char *user,
 int dcc_increment_safeguard(void);
 int dcc_recursion_safeguard(void);
 
+/* clirpc.c */
+int dcc_send_job_corked(int net_fd,
+			char **argv,
+			pid_t cpp_pid,
+			unsigned *status,
+			const char *cpp_fname,
+                        struct dcc_hostdef *);
+
+int dcc_retrieve_results(int net_fd, unsigned *status, const char *output_fname,
+                         struct dcc_hostdef *);
+
 /* climasq.c */
 int dcc_support_masquerade(char *argv[], char *progname, int *);
 
@@ -149,3 +153,16 @@ struct sockaddr;
 
 
 void dcc_set_trace_from_env(void);
+
+
+/* compress.c */
+int dcc_r_bulk_lzo1x(int outf_fd,
+                      int in_fd,
+                      unsigned in_len);
+
+
+
+int dcc_compress_file_lzo1x(int in_fd,
+                            size_t in_len,
+                            char **out_buf,
+                            size_t *out_len);
