@@ -118,6 +118,7 @@ const struct poptOption options[] = {
     { "user", 0,         POPT_ARG_STRING, &opt_user, 'u', 0, 0 },
     { "verbose", 0,      POPT_ARG_NONE, 0, 'v', 0, 0 },
     { "version", 0,      POPT_ARG_NONE, 0, 'V', 0, 0 },
+    { "wizard", 'W',     POPT_ARG_NONE, 0, 'W', 0, 0 },
     { 0, 0, 0, 0, 0, 0, 0 }
 };
 
@@ -146,6 +147,7 @@ static void distccd_show_usage(void)
 "    --no-detach                don't detach from parent (for daemontools, etc)\n"
 "    --log-file=FILE            send messages here instead of syslog\n"
 "    --log-stderr               send messages to stderr\n"
+"    --wizard                   for running under gdb\n"
 "  Mode of operation:\n"
 "    --inetd                    serve client connected to stdin\n"
 "    --daemon                   bind and listen on socket\n"
@@ -219,6 +221,16 @@ int distccd_parse_options(int argc, const char **argv)
             rs_trace_set_level(RS_LOG_DEBUG);
             break;
 
+        case 'W':
+            /* catchall for running under gdb */
+            opt_log_stderr = 1;
+            opt_daemon_mode = 1;
+            opt_no_detach = 1;
+            opt_no_fork = 1;
+            opt_no_fifo = 1;
+            rs_trace_set_level(RS_LOG_DEBUG);
+            break;
+
         default:                /* bad? */
             rs_log(RS_LOG_NONAME|RS_LOG_ERR|RS_LOG_NO_PID, "%s: %s",
                    poptBadOption(po, POPT_BADOPTION_NOALIAS),
