@@ -20,6 +20,11 @@
  * USA
  */
 
+
+/* dopt.c */
+extern struct dcc_allow_list *opt_allowed;
+int distccd_parse_options(int argc, const char *argv[]);
+
 extern int arg_port;
 extern int arg_max_jobs;
 extern const char *arg_pid_file;
