@@ -66,7 +66,9 @@
 #include "exec.h"
 #include "lock.h"
 #include "hosts.h"
+#include "arg.h"
 
+static void dcc_execvp(char **argv) NORETURN;
 
 /* You can't have core files on Windows. */
 #ifndef WCOREDUMP
@@ -124,7 +126,7 @@ int dcc_redirect_fds(const char *stdin_file,
  * Does not return, either execs the compiler in place, or exits with
  * a message.
  **/
-void dcc_execvp(char **argv)
+static void dcc_execvp(char **argv)
 {
     char *slash;
     
