@@ -29,8 +29,6 @@
 #include <string.h>
 #include <errno.h>
 
-#include <sys/stat.h>
-
 #include "distcc.h"
 #include "trace.h"
 #include "util.h"
@@ -40,26 +38,17 @@
 
 /**
  * @file
+ *
  * Everything we know about C filenames.
- **/
-
-
-/*
- * NOTE: As of 0.10, .s and .S files are never distributed, because
+ *
+ * We need to have some heuristics about input and output filenames to
+ * understand command lines, because that's what cc does.
+ *
+ * @note As of 0.10, .s and .S files are never distributed, because
  * they might contain '.include' pseudo-operations, which are resolved
  * by the assembler.
  */
 
-/**
- * XXX: The non-free Intel C compiler (icc) may have trouble with
- * preprocessed C++ source files called .ii.
- *
- * I don't really know a good solution, because if you're compiling
- * C++ with gcc then we need to use the .ii extension.
- *
- * There are two partial solutions: Intel should fix it, or you should
- * use gcc.
- **/
 
 
 /**
@@ -245,6 +234,23 @@ int dcc_is_source(const char *sfile)
 }
 
 
+
+/**
+ * Decide whether @p filename is an object file, based on its
+ * extension.
+ **/
+int dcc_is_object(const char *filename)
+{
+    const char *dot;
+    dot = dcc_find_extension((char *) filename);
+    if (!dot)
+        return 0;
+
+    return !strcmp(dot, ".o");
+}
+    
+
+
 /**
  * Work out the default object file name the compiler would use if -o
  * was not specified.  We don't need to worry about "a.out" because
