@@ -81,6 +81,8 @@ struct dcc_hostdef _dcc_local = {
     NULL,
     4,                          /* number of tasks */
     (char *)"localhost",        /* verbatim string */
+    1,                          /* protocol (ignored) */
+    DCC_COMPRESS_NONE,          /* compression (ignored) */
     NULL    
 };
 
