@@ -83,6 +83,7 @@
 #include "filename.h"
 #include "hosts.h"
 #include "daemon.h"
+#include "arg.h"
 
 
 /**
@@ -91,7 +92,7 @@
  **/
 static int dcc_compile_log_fd = -1;
 
-static int dcc_run_job(int netfd);
+static int dcc_run_job(int in_fd, int out_fd);
 
 
 /**
@@ -140,22 +141,21 @@ static int dcc_remove_log_to_file(void)
 /**
  * Read and execute a job to/from socket @p ifd
  *
- * @todo Split this beast up.
- *
  * @return standard exit code
  **/
-int dcc_service_job(int netfd,
+int dcc_service_job(int in_fd,
+                    int out_fd,
                     struct sockaddr *cli_addr,
                     int cli_len)
 {
     int ret;
 
-    /* TODO: Don't check for ssh connections */
-    /* Log client name and check access if appropriate. */
+    /* Log client name and check access if appropriate.  For ssh connections
+     * the client comes from a localhost socket. */
     if ((ret = dcc_check_client(cli_addr, cli_len)) != 0)
         return ret;
 
-    return dcc_run_job(netfd);
+    return dcc_run_job(in_fd, out_fd);
 }
 
 
@@ -172,17 +172,22 @@ static char *dcc_input_tmpnam(char * orig_input)
 }
 
 
-static int dcc_run_job(int netfd)
+
+/**
+ * Read a request, run the compiler, and send a response.
+ **/
+static int dcc_run_job(int in_fd,
+                       int out_fd)
 {
     char **argv;
     unsigned status;
     char *temp_i, *temp_o, *err_fname, *out_fname;
-    size_t o_size = 0;
     int ret, compile_ret;
     char *orig_input, *orig_output;
-    unsigned i_size;
     pid_t cc_pid;
-
+    enum dcc_protover protover;
+    enum dcc_compress compr;
+    
     err_fname = dcc_make_tmpnam("cc", ".stderr");
     out_fname = dcc_make_tmpnam("cc", ".stdout");
     dcc_remove_if_exists(err_fname);
@@ -199,10 +204,10 @@ static int dcc_run_job(int netfd)
     dcc_ignore_sigpipe(1);
 
     /* Allow output to accumulate into big packets. */
-    tcp_cork_sock(netfd, 1);
+    tcp_cork_sock(out_fd, 1);
 
-    if ((ret = dcc_r_request_header(netfd))
-        || (ret = dcc_r_argv(netfd, &argv))
+    if ((ret = dcc_r_request_header(in_fd, &protover))
+        || (ret = dcc_r_argv(in_fd, &argv))
         || (ret = dcc_scan_args(argv, &orig_input, &orig_output, &argv)))
         goto out_cleanup;
     
@@ -211,8 +216,9 @@ static int dcc_run_job(int netfd)
     temp_i = dcc_input_tmpnam(orig_input);
     temp_o = dcc_make_tmpnam("server", ".o");
 
-    if ((ret = dcc_r_token_int(netfd, "DOTI", &i_size))
-        || (ret = dcc_r_file_timed(netfd, temp_i, (size_t) i_size))
+    compr = (protover == 2) ? DCC_COMPRESS_LZO1X : DCC_COMPRESS_NONE;
+
+    if ((ret = dcc_r_token_file(in_fd, "DOTI", temp_i, compr))
         || (ret = dcc_set_input(argv, temp_i))
         || (ret = dcc_set_output(argv, temp_o)))
         goto out_cleanup;
@@ -223,19 +229,20 @@ static int dcc_run_job(int netfd)
         status = W_EXITCODE(compile_ret, 0);
     }
     
-    if ((ret = dcc_x_result_header(netfd))
-        || (ret = dcc_x_cc_status(netfd, status))
-        || (ret = dcc_x_file(netfd, err_fname, "SERR", NULL))
-        || (ret = dcc_x_file(netfd, out_fname, "SOUT", NULL))
+    if ((ret = dcc_x_result_header(out_fd, protover))
+        || (ret = dcc_x_cc_status(out_fd, status))
+        || (ret = dcc_x_file(out_fd, err_fname, "SERR", compr))
+        || (ret = dcc_x_file(out_fd, out_fname, "SOUT", compr))
         || WIFSIGNALED(status)
         || WEXITSTATUS(status)) {
-        dcc_x_token_int(netfd, "DOTO", 0);
+        /* Something went wrong, so send DOTO 0 */
+        dcc_x_token_int(out_fd, "DOTO", 0);
     } else {
-        ret = dcc_x_file(netfd, temp_o, "DOTO", &o_size);
+        ret = dcc_x_file(out_fd, temp_o, "DOTO", compr);
     }
 
     dcc_critique_status(status, argv[0], dcc_hostdef_local, 0);
-    tcp_cork_sock(netfd, 0);
+    tcp_cork_sock(out_fd, 0);
 
     rs_log(RS_LOG_INFO|RS_LOG_NONAME, "job complete");
 
