@@ -263,13 +263,15 @@ int dcc_trim_path(const char *compiler_name)
         strncpy(buf, p, len);
 
         sprintf(buf + len, "/%s", compiler_name);
-        if (lstat(buf, &sb) == -1 || !S_ISLNK(sb.st_mode))
-            continue;
+        if (lstat(buf, &sb) == -1)
+            continue;           /* ENOENT, EACCESS, etc */
+        if (!S_ISLNK(sb.st_mode))
+            break;
         if ((len = readlink(buf, linkbuf, sizeof linkbuf)) <= 0)
             continue;
         linkbuf[len] = '\0';
         if (strstr(linkbuf, "distcc")
-         || (look_for_ccache_too && strstr(linkbuf, "ccache"))) {
+            || (look_for_ccache_too && strstr(linkbuf, "ccache"))) {
             /* Set newpath to the part of the PATH past our match. */
             newpath = n;
         }
@@ -279,8 +281,7 @@ int dcc_trim_path(const char *compiler_name)
         int ret = dcc_set_path(newpath);
         if (ret)
             return ret;
-    }
-    else
+    } else
         rs_trace("not modifying PATH");
 
     free(buf);
