@@ -41,9 +41,6 @@ Copyright (C) 2002, 2003 by Martin Pool
 
 # TODO: Run the server in a different directory from the clients
 
-# TODO: Compile locally to .s, and assemble remotely; check that
-# works.
-
 # TODO: Some kind of direct test of the host selection algorithm.
 
 # TODO: Optionally run all discc tests under Valgrind, ElectricFence
@@ -120,6 +117,9 @@ Copyright (C) 2002, 2003 by Martin Pool
 
 # TODO: Test compiling a 0-byte source file.  This should be allowed.
 
+# TODO: Test a compiler that produces 0 byte output.  I don't know an
+# easy way to get that out of gcc aside from the Apple port though.
+
 # TODO: Test a compiler that sleeps for a long time; try killing the
 # server and make sure it goes away.
 
@@ -154,6 +154,10 @@ Copyright (C) 2002, 2003 by Martin Pool
 
 # TODO: Check again in --no-prefork mode.
 
+# TODO: Test lzo is parsed properly
+
+# TODO: Test compilation over LZO
+
 
 import time, sys, string, os, types, re, popen2, pprint
 import signal, os.path, string
@@ -276,7 +280,7 @@ class VersionOption_Case(SimpleDistCC_Case):
             assert out[-1] == '\n'
             out = out[:-1]
             line1,trash = string.split(out, '\n')
-            self.assert_re_match(r'^%s [\w.-]+ [.\w-]+ \(protocol 1\) \(default port 3632\)$'
+            self.assert_re_match(r'^%s [\w.-]+ [.\w-]+ \(protocol.*\) \(default port 3632\)$'
                                  % prog, line1)
 
 
@@ -355,7 +359,7 @@ class IsSource_Case(SimpleDistCC_Case):
 
 
 class ScanArgs_Case(SimpleDistCC_Case):
-    '''Test understanding of gcc command lines'''
+    '''Test understanding of gcc command lines.'''
     def runtest(self):
         cases = [("gcc -c hello.c", "distribute", "hello.c", "hello.o"),
                  ("gcc hello.c", "local"),
@@ -382,6 +386,18 @@ class ScanArgs_Case(SimpleDistCC_Case):
                  ("-S -o - foo.c", "local"),
                  ("-c -S -o - foo.c", "local"),
                  ("-S -c -o - foo.c", "local"),
+
+                 # dasho syntax
+                 ("gcc -ofoo.o foo.c -c", "distribute", "foo.c", "foo.o"),
+                 ("gcc -ofoo foo.o", "local"),
+
+                 # tricky this one -- no dashc
+                 ("foo.c -o foo.o", "local"),
+                 ("foo.c -o foo.o -c", "distribute", "foo.c", "foo.o"),
+
+                 # Produce assembly listings
+                 ("gcc -Wa,-alh -c foo.c", "distribute", "foo.c", "foo.o"),
+                 ("gcc -Wa,-alh,-a=foo.lst -c foo.c", "local"),
                  ]
         for tup in cases:
             apply(self.checkScanArgs, tup)
@@ -458,9 +474,14 @@ class ParseHostSpec_Case(SimpleDistCC_Case):
         angry/44
         angry:300/44
         angry/44:300
+        angry,lzo
+        angry:3000,lzo
+        angry/44,lzo
+        @angry,lzo
+        @angry:/usr/sbin/distccd,lzo
         """
 
-        expected="""10
+        expected="""15
    2 LOCAL
    4 TCP 127.0.0.1 3632
    4 SSH (no-user) angry (no-command)
@@ -471,6 +492,11 @@ class ParseHostSpec_Case(SimpleDistCC_Case):
   44 TCP angry 3632
   44 TCP angry 300
   44 TCP angry 300
+   4 TCP angry 3632
+   4 TCP angry 3000
+  44 TCP angry 3632
+   4 SSH (no-user) angry (no-command)
+   4 SSH (no-user) angry /usr/sbin/distccd
 """
         out, err = self.runcmd("DISTCC_HOSTS=\"%s\" h_hosts" % spec)
         assert out == expected, "expected %s\ngot %s" % (`expected`, `out`)
@@ -550,6 +576,11 @@ int main(void) {
         self.assert_equal(msgs, "hello world\n")
 
 
+class DashONoSpace_Case(CompileHello_Case):
+    def compileCmd(self):
+        return "DISTCC_FALLBACK=0 distcc cc -otesttmp.o -c %s" % (self.sourceFilename())
+
+
 class WriteDevNull_Case(CompileHello_Case):
     def runtest(self):
         self.compile()
@@ -1060,6 +1091,7 @@ tests = [BadLogFile_Case,
          StripArgs_Case,
          StartStopDaemon_Case,
          CompileHello_Case,
+         DashONoSpace_Case,
          WriteDevNull_Case,
          CppError_Case,
          BadInclude_Case,
